
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.26.7',
    'branch_nick': 'hotfix-1.26.7',
    'revision_id': '8f832404ae88d6300e17d7e706b40fe58e0df90c',
    'revno': 10883
}
